
# Class: ProcedureConcept




URI: [ks:ProcedureConcept](https://w3id.org/linkml/tests/kitchen_sink/ProcedureConcept)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[MedicalEvent]++-%20procedure%200..1>[ProcedureConcept&#124;id(i):string;name(i):string%20%3F],[Concept]^-[ProcedureConcept],[MedicalEvent],[Concept],[CodeSystem])](https://yuml.me/diagram/nofunky;dir:TB/class/[MedicalEvent]++-%20procedure%200..1>[ProcedureConcept&#124;id(i):string;name(i):string%20%3F],[Concept]^-[ProcedureConcept],[MedicalEvent],[Concept],[CodeSystem])

## Parents

 *  is_a: [Concept](Concept.md)

## Referenced by Class

 *  **None** *[procedure](procedure.md)*  <sub>0..1</sub>  **[ProcedureConcept](ProcedureConcept.md)**

## Attributes


### Inherited from Concept:

 * [id](id.md)  <sub>1..1</sub>
     * Range: [String](types/String.md)
 * [name](name.md)  <sub>0..1</sub>
     * Range: [String](types/String.md)
 * [in code system](in_code_system.md)  <sub>0..1</sub>
     * Range: [CodeSystem](CodeSystem.md)
